// one line to give the program's name and an idea of what it does.
// Copyright (C) 2005  name of Borja Snchez Zamorano
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

using System;
using System.Collections;
using System.Windows.Forms;
using MonoCalendar.i18n;

namespace MonoCalendar {
	
	public class Preferences : System.Windows.Forms.Form
	{
		private System.Windows.Forms.GroupBox groupBoxNotify;
		private System.Windows.Forms.Label label6;
		private System.Windows.Forms.Label label5;
		private System.Windows.Forms.ComboBox comboBoxFirstDay;
		private System.Windows.Forms.GroupBox groupBoxDay;
		private System.Windows.Forms.Label labelUpdate;
		private System.Windows.Forms.Label labelTimeFormat;
		private System.Windows.Forms.ComboBox comboBoxDaysWeek;
		private System.Windows.Forms.Label labelFirstDay;
		private System.Windows.Forms.Label label7;
		private System.Windows.Forms.GroupBox groupBoxTranslucency;
		private System.Windows.Forms.ComboBox comboBoxTimeFormat;
		private System.Windows.Forms.TabControl tabControl1;
		private System.Windows.Forms.ComboBox comboBoxEndHour;
		private System.Windows.Forms.TabPage tabPage1;
		private System.Windows.Forms.TabPage tabPage3;
		private System.Windows.Forms.CheckBox checkBoxNotify;
		private System.Windows.Forms.GroupBox groupBoxUpdates;
		private System.Windows.Forms.ComboBox comboBoxHoursViewed;
		private System.Windows.Forms.ComboBox comboBoxStartHour;
		private System.Windows.Forms.Button buttonClose;
		private System.Windows.Forms.ComboBox comboBoxCheckUpdates;
		private System.Windows.Forms.TrackBar trackBar1;
		private System.Windows.Forms.GroupBox groupBoxLanguage;
		private System.Windows.Forms.Label labelShowHours2;
		private System.Windows.Forms.Label labelShowHours1;
		private System.Windows.Forms.Label labelStartHour;
		private System.Windows.Forms.TabPage tabPage2;
		private System.Windows.Forms.Label labelEndHour;
		private System.Windows.Forms.ListView listViewLanguages;
		private System.Windows.Forms.GroupBox groupBoxTime;
		private System.Windows.Forms.Label labelDaysByWeek;
		private System.Windows.Forms.GroupBox groupBoxWeek;

		class ItemLanguage:IComparable {
			string code;
			string text;
			
			public ItemLanguage(string code, string text)
			{
				this.code = code;
				this.text = text;
			}
			
			public string Code {
				get {
					return code;
				}
				set {
					code = value;
				}
			}
			
			public string Text {
				get {
					return text;
				}
				set {
					text = value;
				}
			}
			
			public int CompareTo (object obj) {
				return text.CompareTo(((ItemLanguage)obj).Text);
			}
		}
		
		ArrayList list;
		
		void LanguageUI()
		{
			list = new ArrayList();
			list.Add(new ItemLanguage("ca-ES", tr.GetString("Catalan")));
			list.Add(new ItemLanguage("cs-CZ", tr.GetString("Czech")));
			list.Add(new ItemLanguage("da-DK", tr.GetString("Danish")));
			list.Add(new ItemLanguage("de-DE", tr.GetString("German")));
			list.Add(new ItemLanguage("en-US", tr.GetString("English")));
			list.Add(new ItemLanguage("es-ES", tr.GetString("Spanish")));
			list.Add(new ItemLanguage("eu-ES", tr.GetString("Basque")));
			list.Add(new ItemLanguage("fr-FR", tr.GetString("French")));
			list.Add(new ItemLanguage("hr-HR", tr.GetString("Croatian")));
			list.Add(new ItemLanguage("hu-HU", tr.GetString("Hungarian")));
			list.Add(new ItemLanguage("it-IT", tr.GetString("Italian")));
			list.Add(new ItemLanguage("ja-JP", tr.GetString("Japanese")));
			list.Add(new ItemLanguage("nl-BE", tr.GetString("Dutch")));
			list.Add(new ItemLanguage("pl-PL", tr.GetString("Polish")));
			list.Add(new ItemLanguage("pt-PT", tr.GetString("Portuguese (Portugal)")));
			list.Add(new ItemLanguage("pt-BR", tr.GetString("Portuguese (Brazil)")));
			list.Add(new ItemLanguage("ru-RU", tr.GetString("Russian")));
			list.Add(new ItemLanguage("sv-SE", tr.GetString("Swedish")));
			list.Add(new ItemLanguage("zh-CN", tr.GetString("Chinese (PRC)")));
			list.Add(new ItemLanguage("zh-TW", tr.GetString("Chinese (Taiwan)")));
			list.Sort();

 			string code = (string) MonoCalendarApp.Config.Get("Language", "en-US");
			int i=0;
			bool finded = false;
			int english = 0;
			foreach (ItemLanguage item in list) {
				if (item.Code == code) {
					finded = true;
					break;
				}
				
				if (item.Code == code.Split('-')[0]) {
					finded = true;
					break;
				}
				if (item.Code == "en-US") english = i;
				i++;
			}

			listViewLanguages.Items.Clear();
			int selected = 0;
			if (finded)
				selected = i;
			else
				selected = english;

			i = 0;
			foreach (ItemLanguage item in list) {
				System.Windows.Forms.ListViewItem aux = new System.Windows.Forms.ListViewItem(item.Text);
				aux.Tag = item.Code;
				if (i==selected) aux.Selected = true;
				listViewLanguages.Items.Add(aux);
				i++;
			}
		}

		public Preferences(int tab)
		{
			InitializeComponent();
			tabControl1.SelectedIndex = tab;
			LanguageUI();
			
			System.DateTime dt;
			dt = System.DateTime.Now;
			while (dt.DayOfWeek != 0) dt = dt.AddDays(1);
			for (int i=0; i<7; i++) {
				comboBoxFirstDay.Items.Add(dt.ToString("dddd"));
				dt = dt.AddDays(1);
			}
			if (5 == (int) MonoCalendarApp.Config.Get("DaysByWeek", (int) 7)) {
				comboBoxDaysWeek.SelectedIndex = 0;
				comboBoxFirstDay.Enabled = false;
			} else {
				comboBoxDaysWeek.SelectedIndex = 1;
				comboBoxFirstDay.Enabled = true;
			}
			
			comboBoxTimeFormat.Items.Add("1:00pm");
			comboBoxTimeFormat.Items.Add("13:00");
			if (0 == (int) MonoCalendarApp.Config.Get("TimeFormat", (int) 1)) {
				comboBoxTimeFormat.SelectedIndex = 0;
			} else {
				comboBoxTimeFormat.SelectedIndex = 1;
			}
			
			System.Globalization.DateTimeFormatInfo dtfi = new System.Globalization.DateTimeFormatInfo();
			
			comboBoxFirstDay.SelectedIndex = int.Parse((MonoCalendarApp.Config.Get("FirstDayOfWeek", (uint) dtfi.FirstDayOfWeek)).ToString());
			
			comboBoxEndHour.SelectedIndex = int.Parse((MonoCalendarApp.Config.Get("EndHour", (int) 8)).ToString())-12;
			comboBoxStartHour.SelectedIndex = int.Parse((MonoCalendarApp.Config.Get("StartHour", (int) 18)).ToString());
			comboBoxHoursViewed.SelectedIndex = int.Parse((MonoCalendarApp.Config.Get("HoursViewed", (uint) 12)).ToString())-6;

			trackBar1.Value = (255-(int) MonoCalendarApp.Config.Get("AlphaEvent", (int) 200));

			comboBoxCheckUpdates.Items.AddRange(new object[] {
						tr.GetString("manual"),
						tr.GetString("daily"),
						tr.GetString("weekly"),
						tr.GetString("monthly")});
			comboBoxCheckUpdates.SelectedIndex = (int) MonoCalendarApp.Config.Get("CheckUpdate", (int) 2);
			checkBoxNotify.Checked = (bool) MonoCalendarApp.Config.Get("NotifyIcon", true);
			Translate();
		}
		
		void Translate()
		{
			LanguageUI();
			System.DateTime dt;
			dt = System.DateTime.Now;
			while (dt.DayOfWeek != 0) dt = dt.AddDays(1);
			for (int i=0; i<7; i++) {
				comboBoxFirstDay.Items[i] = dt.ToString("dddd");
				dt = dt.AddDays(1);
			}
			comboBoxCheckUpdates.Items[0] = tr.GetString("manual");
			comboBoxCheckUpdates.Items[1] = tr.GetString("daily");
			comboBoxCheckUpdates.Items[2] = tr.GetString("weekly");
			comboBoxCheckUpdates.Items[3] = tr.GetString("monthly");
			
			Text = tr.GetString("Preferences");
			buttonClose.Text = tr.GetString("Close");
			groupBoxWeek.Text = tr.GetString("Week");
			groupBoxDay.Text = tr.GetString("Day");
			groupBoxTranslucency.Text = tr.GetString("Translucency");
			groupBoxUpdates.Text = tr.GetString("Updates");
			labelUpdate.Text = tr.GetString("Search updates:");
			labelFirstDay.Text = tr.GetString("First day of week:");
			labelDaysByWeek.Text = tr.GetString("Days by week:");
			labelTimeFormat.Text = tr.GetString("Time format:");
			labelStartHour.Text = tr.GetString("The day begins at:");
			labelEndHour.Text = tr.GetString("The day finishes at:");

			tabPage1.Text = tr.GetString("Calendar");
			tabPage2.Text = tr.GetString("Advanced");
			groupBoxNotify.Text = tr.GetString("Notify icon");
			groupBoxTime.Text = tr.GetString("Time");
			checkBoxNotify.Text = tr.GetString("Show the notify icon of MonoCalendar");
			
			tabPage3.Text = tr.GetString("Language");
			groupBoxLanguage.Text = tr.GetString("Select language");
			
			string text = tr.GetString("Show: % hours");
			labelShowHours1.Text = text.Split('%')[0].Trim();
			labelShowHours2.Text = text.Split('%')[1].Trim();
			
			labelShowHours1.Left = comboBoxHoursViewed.Left - (labelShowHours1.Width + 5);
			labelShowHours2.Left = comboBoxHoursViewed.Right + 5;

			labelFirstDay.Left = comboBoxFirstDay.Left - (labelFirstDay.Width + 5);
			labelDaysByWeek.Left = comboBoxDaysWeek.Left - (labelDaysByWeek.Width + 5);
			labelTimeFormat.Left = comboBoxTimeFormat.Left - (labelTimeFormat.Width + 5);
			labelStartHour.Left = comboBoxStartHour.Left - (labelStartHour.Width + 5);
			labelEndHour.Left = comboBoxEndHour.Left - (labelEndHour.Width + 5);
		}
		
		#region Cdigo generado por el Diseador de Windows Forms
		
		void InitializeComponent() {
			this.groupBoxWeek = new System.Windows.Forms.GroupBox();
			this.labelDaysByWeek = new System.Windows.Forms.Label();
			this.groupBoxTime = new System.Windows.Forms.GroupBox();
			this.listViewLanguages = new System.Windows.Forms.ListView();
			this.labelEndHour = new System.Windows.Forms.Label();
			this.tabPage2 = new System.Windows.Forms.TabPage();
			this.labelStartHour = new System.Windows.Forms.Label();
			this.labelShowHours1 = new System.Windows.Forms.Label();
			this.labelShowHours2 = new System.Windows.Forms.Label();
			this.groupBoxLanguage = new System.Windows.Forms.GroupBox();
			this.trackBar1 = new System.Windows.Forms.TrackBar();
			this.comboBoxCheckUpdates = new System.Windows.Forms.ComboBox();
			this.buttonClose = new System.Windows.Forms.Button();
			this.comboBoxStartHour = new System.Windows.Forms.ComboBox();
			this.comboBoxHoursViewed = new System.Windows.Forms.ComboBox();
			this.groupBoxUpdates = new System.Windows.Forms.GroupBox();
			this.checkBoxNotify = new System.Windows.Forms.CheckBox();
			this.tabPage3 = new System.Windows.Forms.TabPage();
			this.tabPage1 = new System.Windows.Forms.TabPage();
			this.comboBoxEndHour = new System.Windows.Forms.ComboBox();
			this.tabControl1 = new System.Windows.Forms.TabControl();
			this.comboBoxTimeFormat = new System.Windows.Forms.ComboBox();
			this.groupBoxTranslucency = new System.Windows.Forms.GroupBox();
			this.label7 = new System.Windows.Forms.Label();
			this.labelFirstDay = new System.Windows.Forms.Label();
			this.comboBoxDaysWeek = new System.Windows.Forms.ComboBox();
			this.labelTimeFormat = new System.Windows.Forms.Label();
			this.labelUpdate = new System.Windows.Forms.Label();
			this.groupBoxDay = new System.Windows.Forms.GroupBox();
			this.comboBoxFirstDay = new System.Windows.Forms.ComboBox();
			this.label5 = new System.Windows.Forms.Label();
			this.label6 = new System.Windows.Forms.Label();
			this.groupBoxNotify = new System.Windows.Forms.GroupBox();
			this.groupBoxWeek.SuspendLayout();
			this.groupBoxTime.SuspendLayout();
			this.tabPage2.SuspendLayout();
			this.groupBoxLanguage.SuspendLayout();
			((System.ComponentModel.ISupportInitialize)(this.trackBar1)).BeginInit();
			this.groupBoxUpdates.SuspendLayout();
			this.tabPage3.SuspendLayout();
			this.tabPage1.SuspendLayout();
			this.tabControl1.SuspendLayout();
			this.groupBoxTranslucency.SuspendLayout();
			this.groupBoxDay.SuspendLayout();
			this.groupBoxNotify.SuspendLayout();
			this.SuspendLayout();
			// 
			// groupBoxWeek
			// 
			this.groupBoxWeek.Controls.Add(this.comboBoxDaysWeek);
			this.groupBoxWeek.Controls.Add(this.comboBoxFirstDay);
			this.groupBoxWeek.Controls.Add(this.labelFirstDay);
			this.groupBoxWeek.Controls.Add(this.labelDaysByWeek);
			this.groupBoxWeek.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.groupBoxWeek.Location = new System.Drawing.Point(8, 56);
			this.groupBoxWeek.Name = "groupBoxWeek";
			this.groupBoxWeek.Size = new System.Drawing.Size(272, 82);
			this.groupBoxWeek.TabIndex = 1;
			this.groupBoxWeek.TabStop = false;
			this.groupBoxWeek.Text = "Week";
			// 
			// labelDaysByWeek
			// 
			this.labelDaysByWeek.AutoSize = true;
			this.labelDaysByWeek.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.labelDaysByWeek.ImeMode = System.Windows.Forms.ImeMode.NoControl;
			this.labelDaysByWeek.Location = new System.Drawing.Point(22, 24);
			this.labelDaysByWeek.Name = "labelDaysByWeek";
			this.labelDaysByWeek.Size = new System.Drawing.Size(101, 16);
			this.labelDaysByWeek.TabIndex = 2;
			this.labelDaysByWeek.Text = "Días por semana:";
			this.labelDaysByWeek.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// groupBoxTime
			// 
			this.groupBoxTime.Controls.Add(this.labelTimeFormat);
			this.groupBoxTime.Controls.Add(this.comboBoxTimeFormat);
			this.groupBoxTime.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.groupBoxTime.Location = new System.Drawing.Point(8, 8);
			this.groupBoxTime.Name = "groupBoxTime";
			this.groupBoxTime.Size = new System.Drawing.Size(272, 48);
			this.groupBoxTime.TabIndex = 0;
			this.groupBoxTime.TabStop = false;
			this.groupBoxTime.Text = "Time";
			// 
			// listViewLanguages
			// 
			this.listViewLanguages.HideSelection = false;
			this.listViewLanguages.Location = new System.Drawing.Point(8, 24);
			this.listViewLanguages.MultiSelect = false;
			this.listViewLanguages.Name = "listViewLanguages";
			this.listViewLanguages.Size = new System.Drawing.Size(264, 160);
			this.listViewLanguages.TabIndex = 3;
			this.listViewLanguages.View = System.Windows.Forms.View.List;
			this.listViewLanguages.Click += new System.EventHandler(this.ListViewLanguagesClick);
			this.listViewLanguages.SelectedIndexChanged += new System.EventHandler(this.listViewLanguagesSelectedIndexChanged);
			// 
			// labelEndHour
			// 
			this.labelEndHour.AutoSize = true;
			this.labelEndHour.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.labelEndHour.ImageAlign = System.Drawing.ContentAlignment.MiddleRight;
			this.labelEndHour.ImeMode = System.Windows.Forms.ImeMode.NoControl;
			this.labelEndHour.Location = new System.Drawing.Point(16, 50);
			this.labelEndHour.Name = "labelEndHour";
			this.labelEndHour.Size = new System.Drawing.Size(112, 16);
			this.labelEndHour.TabIndex = 5;
			this.labelEndHour.Text = "El día termina a las:";
			this.labelEndHour.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// tabPage2
			// 
			this.tabPage2.Controls.Add(this.groupBoxUpdates);
			this.tabPage2.Controls.Add(this.groupBoxNotify);
			this.tabPage2.Location = new System.Drawing.Point(4, 22);
			this.tabPage2.Name = "tabPage2";
			this.tabPage2.Size = new System.Drawing.Size(288, 335);
			this.tabPage2.TabIndex = 1;
			this.tabPage2.Text = "Advanced";
			// 
			// labelStartHour
			// 
			this.labelStartHour.AutoSize = true;
			this.labelStartHour.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.labelStartHour.ImageAlign = System.Drawing.ContentAlignment.MiddleRight;
			this.labelStartHour.ImeMode = System.Windows.Forms.ImeMode.NoControl;
			this.labelStartHour.Location = new System.Drawing.Point(8, 18);
			this.labelStartHour.Name = "labelStartHour";
			this.labelStartHour.Size = new System.Drawing.Size(123, 16);
			this.labelStartHour.TabIndex = 3;
			this.labelStartHour.Text = "El día comienza a las:";
			this.labelStartHour.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// labelShowHours1
			// 
			this.labelShowHours1.AutoSize = true;
			this.labelShowHours1.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.labelShowHours1.ImeMode = System.Windows.Forms.ImeMode.NoControl;
			this.labelShowHours1.Location = new System.Drawing.Point(74, 82);
			this.labelShowHours1.Name = "labelShowHours1";
			this.labelShowHours1.Size = new System.Drawing.Size(46, 16);
			this.labelShowHours1.TabIndex = 2;
			this.labelShowHours1.Text = "Mostrar:";
			this.labelShowHours1.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// labelShowHours2
			// 
			this.labelShowHours2.AutoSize = true;
			this.labelShowHours2.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.labelShowHours2.ImeMode = System.Windows.Forms.ImeMode.NoControl;
			this.labelShowHours2.Location = new System.Drawing.Point(184, 82);
			this.labelShowHours2.Name = "labelShowHours2";
			this.labelShowHours2.Size = new System.Drawing.Size(74, 16);
			this.labelShowHours2.TabIndex = 2;
			this.labelShowHours2.Text = "horas a la vez";
			this.labelShowHours2.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// groupBoxLanguage
			// 
			this.groupBoxLanguage.Controls.Add(this.listViewLanguages);
			this.groupBoxLanguage.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.groupBoxLanguage.Location = new System.Drawing.Point(8, 7);
			this.groupBoxLanguage.Name = "groupBoxLanguage";
			this.groupBoxLanguage.Size = new System.Drawing.Size(280, 193);
			this.groupBoxLanguage.TabIndex = 1;
			this.groupBoxLanguage.TabStop = false;
			this.groupBoxLanguage.Text = "Seleccione lenguaje";
			// 
			// trackBar1
			// 
			this.trackBar1.AutoSize = false;
			this.trackBar1.ImeMode = System.Windows.Forms.ImeMode.NoControl;
			this.trackBar1.Location = new System.Drawing.Point(8, 15);
			this.trackBar1.Maximum = 204;
			this.trackBar1.Name = "trackBar1";
			this.trackBar1.Size = new System.Drawing.Size(256, 22);
			this.trackBar1.TabIndex = 0;
			this.trackBar1.TickStyle = System.Windows.Forms.TickStyle.None;
			this.trackBar1.Scroll += new System.EventHandler(this.TrackBar1Scroll);
			// 
			// comboBoxCheckUpdates
			// 
			this.comboBoxCheckUpdates.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.comboBoxCheckUpdates.Location = new System.Drawing.Point(100, 30);
			this.comboBoxCheckUpdates.Name = "comboBoxCheckUpdates";
			this.comboBoxCheckUpdates.Size = new System.Drawing.Size(116, 21);
			this.comboBoxCheckUpdates.TabIndex = 1;
			this.comboBoxCheckUpdates.SelectedIndexChanged += new System.EventHandler(this.ComboBoxUpdateSelectedIndexChanged);
			// 
			// buttonClose
			// 
			this.buttonClose.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.buttonClose.ImeMode = System.Windows.Forms.ImeMode.NoControl;
			this.buttonClose.Location = new System.Drawing.Point(221, 376);
			this.buttonClose.Name = "buttonClose";
			this.buttonClose.Size = new System.Drawing.Size(75, 21);
			this.buttonClose.TabIndex = 3;
			this.buttonClose.Text = "Cerrar";
			this.buttonClose.Click += new System.EventHandler(this.ButtonCloseClick);
			// 
			// comboBoxStartHour
			// 
			this.comboBoxStartHour.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.comboBoxStartHour.ItemHeight = 13;
			this.comboBoxStartHour.Items.AddRange(new object[] {
						"24:00",
						"1:00",
						"2:00",
						"3:00",
						"4:00",
						"5:00",
						"6:00",
						"7:00",
						"8:00",
						"9:00",
						"10:00",
						"11:00",
						"12:00"});
			this.comboBoxStartHour.Location = new System.Drawing.Point(128, 16);
			this.comboBoxStartHour.Name = "comboBoxStartHour";
			this.comboBoxStartHour.Size = new System.Drawing.Size(88, 21);
			this.comboBoxStartHour.TabIndex = 0;
			this.comboBoxStartHour.SelectedIndexChanged += new System.EventHandler(this.ComboBoxStartHourSelectedIndexChanged);
			// 
			// comboBoxHoursViewed
			// 
			this.comboBoxHoursViewed.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.comboBoxHoursViewed.ItemHeight = 13;
			this.comboBoxHoursViewed.Items.AddRange(new object[] {
						"6",
						"7",
						"8",
						"9",
						"10",
						"11",
						"12",
						"13",
						"14",
						"15",
						"16",
						"17",
						"18",
						"19",
						"20",
						"21",
						"22",
						"23",
						"24"});
			this.comboBoxHoursViewed.Location = new System.Drawing.Point(128, 80);
			this.comboBoxHoursViewed.Name = "comboBoxHoursViewed";
			this.comboBoxHoursViewed.Size = new System.Drawing.Size(56, 21);
			this.comboBoxHoursViewed.TabIndex = 2;
			this.comboBoxHoursViewed.SelectedIndexChanged += new System.EventHandler(this.ComboBoxHoursViewedSelectedIndexChanged);
			// 
			// groupBoxUpdates
			// 
			this.groupBoxUpdates.Controls.Add(this.comboBoxCheckUpdates);
			this.groupBoxUpdates.Controls.Add(this.labelUpdate);
			this.groupBoxUpdates.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.groupBoxUpdates.Location = new System.Drawing.Point(8, 74);
			this.groupBoxUpdates.Name = "groupBoxUpdates";
			this.groupBoxUpdates.Size = new System.Drawing.Size(264, 60);
			this.groupBoxUpdates.TabIndex = 1;
			this.groupBoxUpdates.TabStop = false;
			this.groupBoxUpdates.Text = "Actualizaciones";
			// 
			// checkBoxNotify
			// 
			this.checkBoxNotify.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.checkBoxNotify.ImeMode = System.Windows.Forms.ImeMode.NoControl;
			this.checkBoxNotify.Location = new System.Drawing.Point(8, 22);
			this.checkBoxNotify.Name = "checkBoxNotify";
			this.checkBoxNotify.Size = new System.Drawing.Size(208, 23);
			this.checkBoxNotify.TabIndex = 0;
			this.checkBoxNotify.Text = "Show the notify icon of MonoCalendar";
			this.checkBoxNotify.CheckedChanged += new System.EventHandler(this.CheckBoxNotifyCheckedChanged);
			// 
			// tabPage3
			// 
			this.tabPage3.Controls.Add(this.groupBoxLanguage);
			this.tabPage3.Location = new System.Drawing.Point(4, 22);
			this.tabPage3.Name = "tabPage3";
			this.tabPage3.Size = new System.Drawing.Size(288, 335);
			this.tabPage3.TabIndex = 2;
			this.tabPage3.Text = "Language";
			// 
			// tabPage1
			// 
			this.tabPage1.Controls.Add(this.groupBoxTime);
			this.tabPage1.Controls.Add(this.groupBoxTranslucency);
			this.tabPage1.Controls.Add(this.groupBoxDay);
			this.tabPage1.Controls.Add(this.groupBoxWeek);
			this.tabPage1.Location = new System.Drawing.Point(4, 22);
			this.tabPage1.Name = "tabPage1";
			this.tabPage1.Size = new System.Drawing.Size(288, 335);
			this.tabPage1.TabIndex = 0;
			this.tabPage1.Text = "Calendar";
			// 
			// comboBoxEndHour
			// 
			this.comboBoxEndHour.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.comboBoxEndHour.ItemHeight = 13;
			this.comboBoxEndHour.Items.AddRange(new object[] {
						"12:00",
						"13:00",
						"14:00",
						"15:00",
						"16:00",
						"17:00",
						"18:00",
						"19:00",
						"20:00",
						"21:00",
						"22:00",
						"23:00",
						"24:00"});
			this.comboBoxEndHour.Location = new System.Drawing.Point(128, 48);
			this.comboBoxEndHour.Name = "comboBoxEndHour";
			this.comboBoxEndHour.Size = new System.Drawing.Size(88, 21);
			this.comboBoxEndHour.TabIndex = 1;
			this.comboBoxEndHour.SelectedIndexChanged += new System.EventHandler(this.ComboBoxEndHourSelectedIndexChanged);
			// 
			// tabControl1
			// 
			this.tabControl1.Controls.Add(this.tabPage1);
			this.tabControl1.Controls.Add(this.tabPage3);
			this.tabControl1.Controls.Add(this.tabPage2);
			this.tabControl1.ItemSize = new System.Drawing.Size(54, 18);
			this.tabControl1.Location = new System.Drawing.Point(8, 7);
			this.tabControl1.Name = "tabControl1";
			this.tabControl1.SelectedIndex = 0;
			this.tabControl1.Size = new System.Drawing.Size(296, 361);
			this.tabControl1.TabIndex = 0;
			this.tabControl1.SelectedIndexChanged += new System.EventHandler(this.TabControl1SelectedIndexChanged);
			// 
			// comboBoxTimeFormat
			// 
			this.comboBoxTimeFormat.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.comboBoxTimeFormat.Location = new System.Drawing.Point(128, 16);
			this.comboBoxTimeFormat.Name = "comboBoxTimeFormat";
			this.comboBoxTimeFormat.Size = new System.Drawing.Size(96, 21);
			this.comboBoxTimeFormat.TabIndex = 0;
			this.comboBoxTimeFormat.SelectedIndexChanged += new System.EventHandler(this.ComboBoxTimeFormatSelectedIndexChanged);
			// 
			// groupBoxTranslucency
			// 
			this.groupBoxTranslucency.Controls.Add(this.label7);
			this.groupBoxTranslucency.Controls.Add(this.label6);
			this.groupBoxTranslucency.Controls.Add(this.label5);
			this.groupBoxTranslucency.Controls.Add(this.trackBar1);
			this.groupBoxTranslucency.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.groupBoxTranslucency.Location = new System.Drawing.Point(8, 264);
			this.groupBoxTranslucency.Name = "groupBoxTranslucency";
			this.groupBoxTranslucency.Size = new System.Drawing.Size(272, 59);
			this.groupBoxTranslucency.TabIndex = 3;
			this.groupBoxTranslucency.TabStop = false;
			this.groupBoxTranslucency.Text = "Transparencia";
			// 
			// label7
			// 
			this.label7.AutoSize = true;
			this.label7.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.label7.ImeMode = System.Windows.Forms.ImeMode.NoControl;
			this.label7.Location = new System.Drawing.Point(236, 37);
			this.label7.Name = "label7";
			this.label7.Size = new System.Drawing.Size(27, 16);
			this.label7.TabIndex = 3;
			this.label7.Text = "80%";
			this.label7.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// labelFirstDay
			// 
			this.labelFirstDay.AutoSize = true;
			this.labelFirstDay.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.labelFirstDay.ImeMode = System.Windows.Forms.ImeMode.NoControl;
			this.labelFirstDay.Location = new System.Drawing.Point(8, 54);
			this.labelFirstDay.Name = "labelFirstDay";
			this.labelFirstDay.Size = new System.Drawing.Size(105, 16);
			this.labelFirstDay.TabIndex = 0;
			this.labelFirstDay.Text = "Iniciar la semana el:";
			this.labelFirstDay.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// comboBoxDaysWeek
			// 
			this.comboBoxDaysWeek.DisplayMember = "5";
			this.comboBoxDaysWeek.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.comboBoxDaysWeek.ItemHeight = 13;
			this.comboBoxDaysWeek.Items.AddRange(new object[] {
						"5",
						"7"});
			this.comboBoxDaysWeek.Location = new System.Drawing.Point(128, 22);
			this.comboBoxDaysWeek.Name = "comboBoxDaysWeek";
			this.comboBoxDaysWeek.Size = new System.Drawing.Size(96, 21);
			this.comboBoxDaysWeek.TabIndex = 0;
			this.comboBoxDaysWeek.SelectedIndexChanged += new System.EventHandler(this.ComboBoxDaysWeekSelectedIndexChanged);
			// 
			// labelTimeFormat
			// 
			this.labelTimeFormat.AutoSize = true;
			this.labelTimeFormat.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.labelTimeFormat.Location = new System.Drawing.Point(48, 18);
			this.labelTimeFormat.Name = "labelTimeFormat";
			this.labelTimeFormat.Size = new System.Drawing.Size(68, 16);
			this.labelTimeFormat.TabIndex = 1;
			this.labelTimeFormat.Text = "Time format:";
			this.labelTimeFormat.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// labelUpdate
			// 
			this.labelUpdate.AutoSize = true;
			this.labelUpdate.Location = new System.Drawing.Point(8, 32);
			this.labelUpdate.Name = "labelUpdate";
			this.labelUpdate.Size = new System.Drawing.Size(83, 16);
			this.labelUpdate.TabIndex = 0;
			this.labelUpdate.Text = "Check updates:";
			this.labelUpdate.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// groupBoxDay
			// 
			this.groupBoxDay.Controls.Add(this.comboBoxEndHour);
			this.groupBoxDay.Controls.Add(this.labelEndHour);
			this.groupBoxDay.Controls.Add(this.comboBoxStartHour);
			this.groupBoxDay.Controls.Add(this.labelStartHour);
			this.groupBoxDay.Controls.Add(this.labelShowHours1);
			this.groupBoxDay.Controls.Add(this.comboBoxHoursViewed);
			this.groupBoxDay.Controls.Add(this.labelShowHours2);
			this.groupBoxDay.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.groupBoxDay.Location = new System.Drawing.Point(8, 144);
			this.groupBoxDay.Name = "groupBoxDay";
			this.groupBoxDay.Size = new System.Drawing.Size(272, 112);
			this.groupBoxDay.TabIndex = 2;
			this.groupBoxDay.TabStop = false;
			this.groupBoxDay.Text = "Da";
			// 
			// comboBoxFirstDay
			// 
			this.comboBoxFirstDay.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.comboBoxFirstDay.ItemHeight = 13;
			this.comboBoxFirstDay.Location = new System.Drawing.Point(128, 52);
			this.comboBoxFirstDay.Name = "comboBoxFirstDay";
			this.comboBoxFirstDay.Size = new System.Drawing.Size(96, 21);
			this.comboBoxFirstDay.TabIndex = 1;
			this.comboBoxFirstDay.SelectedIndexChanged += new System.EventHandler(this.ComboBoxFirstDaySelectedIndexChanged);
			// 
			// label5
			// 
			this.label5.AutoSize = true;
			this.label5.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.label5.ImageAlign = System.Drawing.ContentAlignment.MiddleLeft;
			this.label5.ImeMode = System.Windows.Forms.ImeMode.NoControl;
			this.label5.Location = new System.Drawing.Point(8, 37);
			this.label5.Name = "label5";
			this.label5.Size = new System.Drawing.Size(21, 16);
			this.label5.TabIndex = 1;
			this.label5.Text = "0%";
			this.label5.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label6
			// 
			this.label6.AutoSize = true;
			this.label6.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.label6.ImeMode = System.Windows.Forms.ImeMode.NoControl;
			this.label6.Location = new System.Drawing.Point(122, 37);
			this.label6.Name = "label6";
			this.label6.Size = new System.Drawing.Size(27, 16);
			this.label6.TabIndex = 2;
			this.label6.Text = "40%";
			this.label6.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			// 
			// groupBoxNotify
			// 
			this.groupBoxNotify.Controls.Add(this.checkBoxNotify);
			this.groupBoxNotify.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.groupBoxNotify.Location = new System.Drawing.Point(8, 7);
			this.groupBoxNotify.Name = "groupBoxNotify";
			this.groupBoxNotify.Size = new System.Drawing.Size(264, 60);
			this.groupBoxNotify.TabIndex = 0;
			this.groupBoxNotify.TabStop = false;
			this.groupBoxNotify.Text = "Notify icon";
			// 
			// Preferences
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(306, 407);
			this.ControlBox = false;
			this.Controls.Add(this.tabControl1);
			this.Controls.Add(this.buttonClose);
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
			this.MaximizeBox = false;
			this.MinimizeBox = false;
			this.Name = "Preferences";
			this.ShowInTaskbar = false;
			this.StartPosition = System.Windows.Forms.FormStartPosition.CenterParent;
			this.Text = "Preferencias";
			this.Layout += new System.Windows.Forms.LayoutEventHandler(this.PreferencesLayout);
			this.groupBoxWeek.ResumeLayout(false);
			this.groupBoxTime.ResumeLayout(false);
			this.tabPage2.ResumeLayout(false);
			this.groupBoxLanguage.ResumeLayout(false);
			((System.ComponentModel.ISupportInitialize)(this.trackBar1)).EndInit();
			this.groupBoxUpdates.ResumeLayout(false);
			this.tabPage3.ResumeLayout(false);
			this.tabPage1.ResumeLayout(false);
			this.tabControl1.ResumeLayout(false);
			this.groupBoxTranslucency.ResumeLayout(false);
			this.groupBoxDay.ResumeLayout(false);
			this.groupBoxNotify.ResumeLayout(false);
			this.ResumeLayout(false);
		}
		
		#endregion
		
		void ButtonCloseClick(object sender, System.EventArgs e)
		{
			this.Close();
		}
		
		void ComboBoxDaysWeekSelectedIndexChanged(object sender, System.EventArgs e)
		{
			if (comboBoxDaysWeek.SelectedIndex == 0) {
				comboBoxFirstDay.Enabled = false;
				MonoCalendarApp.Config.Set("DaysByWeek", (int) 5);
			} else {
				comboBoxFirstDay.Enabled = true;
				MonoCalendarApp.Config.Set("DaysByWeek", (int) 7);
			}
		}
		
		void ComboBoxFirstDaySelectedIndexChanged(object sender, System.EventArgs e)
		{
			MonoCalendarApp.Config.Set("FirstDayOfWeek", (uint) comboBoxFirstDay.SelectedIndex);
		}
		
		void TrackBar1Scroll(object sender, System.EventArgs e)
		{
			MonoCalendarApp.Config.Set("AlphaEvent", (int) (255-trackBar1.Value));
		}

		void ComboBoxUpdateSelectedIndexChanged(object sender, System.EventArgs e)
		{
			MonoCalendarApp.Config.Set("CheckUpdate", (int) comboBoxCheckUpdates.SelectedIndex);
		}

		void CheckBoxNotifyCheckedChanged(object sender, System.EventArgs e)
		{
			MonoCalendarApp.Config.Set("NotifyIcon", (bool) checkBoxNotify.Checked);
		}
		
		void setSize(int width, int height)
		{
			tabControl1.Height = height;
			tabControl1.Width = width;
			buttonClose.Top = tabControl1.Bottom + 8;
			buttonClose.Left = tabControl1.Right - buttonClose.Width;

			this.SetClientSizeCore(tabControl1.Right + 8, buttonClose.Bottom + 8);
		}
		
		void UpdateDimensions() {
			switch (tabControl1.SelectedIndex) {
				case 0:
					setSize(groupBoxWeek.Right + (tabControl1.Width - tabPage1.Width) + 10, groupBoxTranslucency.Bottom + (tabControl1.Height - tabPage1.Height) + 10);
					break;
				case 1:
//					labelLanguages.Left = 8;
//					comboBoxLanguages.Left = labelLanguages.Right + 5;
//					groupBoxLanguage.Width = comboBoxLanguages.Right + 10;
					setSize(groupBoxLanguage.Right + (tabControl1.Width - tabPage3.Width) + 10, groupBoxLanguage.Bottom + (tabControl1.Height - tabPage3.Height) + 10);
					break;
				case 2:
					labelUpdate.Left = 8;
					comboBoxCheckUpdates.Left = labelUpdate.Right;
					groupBoxUpdates.Width = comboBoxCheckUpdates.Right + 10;
					groupBoxNotify.Width = groupBoxUpdates.Width;					
					setSize(groupBoxUpdates.Right + (tabControl1.Width - tabPage2.Width) + 10, groupBoxUpdates.Bottom + (tabControl1.Height - tabPage2.Height) + 10);
					break;
			}
		}
		
		void TabControl1SelectedIndexChanged(object sender, System.EventArgs e)
		{
			UpdateDimensions();
		}
		
		void PreferencesLayout(object sender, System.Windows.Forms.LayoutEventArgs e)
		{
			UpdateDimensions();
		}

		void ComboBoxTimeFormatSelectedIndexChanged(object sender, System.EventArgs e)
		{
			MonoCalendarApp.Config.Set("TimeFormat", (int) comboBoxTimeFormat.SelectedIndex);
		}

		void ComboBoxEndHourSelectedIndexChanged(object sender, System.EventArgs e)
		{
			MonoCalendarApp.Config.Set("EndHour", (int) (12 + comboBoxEndHour.SelectedIndex));
		}
		
		void ComboBoxStartHourSelectedIndexChanged(object sender, System.EventArgs e)
		{
			MonoCalendarApp.Config.Set("StartHour", (int) comboBoxStartHour.SelectedIndex);
		}

		void ComboBoxHoursViewedSelectedIndexChanged(object sender, System.EventArgs e)
		{
			MonoCalendarApp.Config.Set("HoursViewed", (uint) (6 + comboBoxHoursViewed.SelectedIndex));
		}
		
		void listViewLanguagesSelectedIndexChanged(object sender, System.EventArgs e)
		{
			System.Windows.Forms.ListView.SelectedIndexCollection indexes = listViewLanguages.SelectedIndices;

			int selected = -1;
			foreach ( int index in indexes ) {
				selected = index;
			}
			if (selected == -1) return;

			ItemLanguage aux = (ItemLanguage) list[selected];
        	
			string aux2 = (string) MonoCalendarApp.Config.Get("Language", "en-US");
			MonoCalendarApp.Config.Set("Language", aux.Code);
			if (aux.Code != aux2) Translate();
			UpdateDimensions();
		}

		void ListViewLanguagesClick(object sender, System.EventArgs e)
		{
			Translate();
		}
	}
}
